@@ -22,8 +22,16 @@ class WSGI(BaseInterface):
         r.query = raw_request['QUERY_STRING']
         r.raw_request = raw_request
 
-        if r.is_method('POST'):
-            r.body = raw_request['wsgi.input'].read()
+        # handle headers not prefixed with http
+        k = 'CONTENT_TYPE'
+        ct = r.environ.pop(k, None)
+        if ct:
+            r.headers[k] = ct
+
+        if 'wsgi.input' in raw_request:
+            body = raw_request['wsgi.input'].read()
+            if not body: body = None
+            r.body = body
 
         else:
             r.body = None
